aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/dom/bindings/root.rs
diff options
context:
space:
mode:
authorNicholas Nethercote <nnethercote@mozilla.com>2017-10-18 10:42:01 +1100
committerNicholas Nethercote <nnethercote@mozilla.com>2017-10-18 22:20:37 +1100
commit4506f0d30cbbb02df32e9c16135ef288ad6b7e2e (patch)
tree9a3de6bfdfabc6dee92352fb18df31e2468acf07 /components/script/dom/bindings/root.rs
parent421baa854ea40c7b1a3d1e75acac14da04a3fbcc (diff)
downloadservo-4506f0d30cbbb02df32e9c16135ef288ad6b7e2e.tar.gz
servo-4506f0d30cbbb02df32e9c16135ef288ad6b7e2e.zip
Replace all uses of the `heapsize` crate with `malloc_size_of`.
Servo currently uses `heapsize`, but Stylo/Gecko use `malloc_size_of`. `malloc_size_of` is better -- it handles various cases that `heapsize` does not -- so this patch changes Servo to use `malloc_size_of`. This patch makes the following changes to the `malloc_size_of` crate. - Adds `MallocSizeOf` trait implementations for numerous types, some built-in (e.g. `VecDeque`), some external and Servo-only (e.g. `string_cache`). - Makes `enclosing_size_of_op` optional, because vanilla jemalloc doesn't support that operation. - For `HashSet`/`HashMap`, falls back to a computed estimate when `enclosing_size_of_op` isn't available. - Adds an extern "C" `malloc_size_of` function that does the actual heap measurement; this is based on the same functions from the `heapsize` crate. This patch makes the following changes elsewhere. - Converts all the uses of `heapsize` to instead use `malloc_size_of`. - Disables the "heapsize"/"heap_size" feature for the external crates that provide it. - Removes the `HeapSizeOf` implementation from `hashglobe`. - Adds `ignore` annotations to a few `Rc`/`Arc`, because `malloc_size_of` doesn't derive those types, unlike `heapsize`.
Diffstat (limited to 'components/script/dom/bindings/root.rs')
-rw-r--r--components/script/dom/bindings/root.rs32
1 files changed, 16 insertions, 16 deletions
diff --git a/components/script/dom/bindings/root.rs b/components/script/dom/bindings/root.rs
index e2c474cafd5..636c14b4d5c 100644
--- a/components/script/dom/bindings/root.rs
+++ b/components/script/dom/bindings/root.rs
@@ -30,9 +30,9 @@ use dom::bindings::reflector::{DomObject, Reflector};
use dom::bindings::trace::JSTraceable;
use dom::bindings::trace::trace_reflector;
use dom::node::Node;
-use heapsize::HeapSizeOf;
use js::jsapi::{JSObject, JSTracer, Heap};
use js::rust::GCMethods;
+use malloc_size_of::{MallocSizeOf, MallocSizeOfOps};
use mitochondria::OnceCell;
use nonzero::NonZero;
use script_layout_interface::TrustedNodeAddress;
@@ -157,12 +157,12 @@ impl<T: DomObject> DomRoot<T> {
}
}
-impl<T> HeapSizeOf for DomRoot<T>
+impl<T> MallocSizeOf for DomRoot<T>
where
- T: DomObject + HeapSizeOf,
+ T: DomObject + MallocSizeOf,
{
- fn heap_size_of_children(&self) -> usize {
- (**self).heap_size_of_children()
+ fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize {
+ (**self).size_of(ops)
}
}
@@ -317,8 +317,8 @@ pub struct Dom<T> {
// Dom<T> is similar to Rc<T>, in that it's not always clear how to avoid double-counting.
// For now, we choose not to follow any such pointers.
-impl<T> HeapSizeOf for Dom<T> {
- fn heap_size_of_children(&self) -> usize {
+impl<T> MallocSizeOf for Dom<T> {
+ fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize {
0
}
}
@@ -516,9 +516,9 @@ impl<T: DomObject> MutDom<T> {
}
}
-impl<T: DomObject> HeapSizeOf for MutDom<T> {
- fn heap_size_of_children(&self) -> usize {
- // See comment on HeapSizeOf for Dom<T>.
+impl<T: DomObject> MallocSizeOf for MutDom<T> {
+ fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize {
+ // See comment on MallocSizeOf for Dom<T>.
0
}
}
@@ -635,9 +635,9 @@ impl<T: DomObject> Default for MutNullableDom<T> {
}
}
-impl<T: DomObject> HeapSizeOf for MutNullableDom<T> {
- fn heap_size_of_children(&self) -> usize {
- // See comment on HeapSizeOf for Dom<T>.
+impl<T: DomObject> MallocSizeOf for MutNullableDom<T> {
+ fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize {
+ // See comment on MallocSizeOf for Dom<T>.
0
}
}
@@ -678,9 +678,9 @@ impl<T: DomObject> Default for DomOnceCell<T> {
}
}
-impl<T: DomObject> HeapSizeOf for DomOnceCell<T> {
- fn heap_size_of_children(&self) -> usize {
- // See comment on HeapSizeOf for Dom<T>.
+impl<T: DomObject> MallocSizeOf for DomOnceCell<T> {
+ fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize {
+ // See comment on MallocSizeOf for Dom<T>.
0
}
}